# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: control.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='control.proto',
  package='io.casperlabs.node.api.control',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\rcontrol.proto\x12\x1eio.casperlabs.node.api.control\x1a\x11\x61nnotations.proto\"\x10\n\x0eProposeRequest\"%\n\x0fProposeResponse\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x32\x95\x01\n\x0e\x43ontrolService\x12\x82\x01\n\x07Propose\x12..io.casperlabs.node.api.control.ProposeRequest\x1a/.io.casperlabs.node.api.control.ProposeResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v2:propose:\x01*b\x06proto3'
  ,
  dependencies=[annotations__pb2.DESCRIPTOR,])




_PROPOSEREQUEST = _descriptor.Descriptor(
  name='ProposeRequest',
  full_name='io.casperlabs.node.api.control.ProposeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=84,
)


_PROPOSERESPONSE = _descriptor.Descriptor(
  name='ProposeResponse',
  full_name='io.casperlabs.node.api.control.ProposeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.node.api.control.ProposeResponse.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=123,
)

DESCRIPTOR.message_types_by_name['ProposeRequest'] = _PROPOSEREQUEST
DESCRIPTOR.message_types_by_name['ProposeResponse'] = _PROPOSERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProposeRequest = _reflection.GeneratedProtocolMessageType('ProposeRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSEREQUEST,
  '__module__' : 'control_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.control.ProposeRequest)
  })
_sym_db.RegisterMessage(ProposeRequest)

ProposeResponse = _reflection.GeneratedProtocolMessageType('ProposeResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSERESPONSE,
  '__module__' : 'control_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.control.ProposeResponse)
  })
_sym_db.RegisterMessage(ProposeResponse)



_CONTROLSERVICE = _descriptor.ServiceDescriptor(
  name='ControlService',
  full_name='io.casperlabs.node.api.control.ControlService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=126,
  serialized_end=275,
  methods=[
  _descriptor.MethodDescriptor(
    name='Propose',
    full_name='io.casperlabs.node.api.control.ControlService.Propose',
    index=0,
    containing_service=None,
    input_type=_PROPOSEREQUEST,
    output_type=_PROPOSERESPONSE,
    serialized_options=b'\202\323\344\223\002\020\"\013/v2:propose:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_CONTROLSERVICE)

DESCRIPTOR.services_by_name['ControlService'] = _CONTROLSERVICE

# @@protoc_insertion_point(module_scope)
