# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: casper.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2
from . import empty_pb2 as empty__pb2
from . import consensus_pb2 as consensus__pb2
from . import info_pb2 as info__pb2
from . import state_pb2 as state__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='casper.proto',
  package='io.casperlabs.node.api.casper',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x0c\x63\x61sper.proto\x12\x1dio.casperlabs.node.api.casper\x1a\x11\x61nnotations.proto\x1a\x0b\x65mpty.proto\x1a\x0f\x63onsensus.proto\x1a\ninfo.proto\x1a\x0bstate.proto\"G\n\rDeployRequest\x12\x36\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32&.io.casperlabs.casper.consensus.Deploy\"\x87\x01\n\x13GetBlockInfoRequest\x12\x19\n\x11\x62lock_hash_base16\x18\x01 \x01(\t\x12\x12\n\nblock_hash\x18\x03 \x01(\x0c\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\x33.io.casperlabs.casper.consensus.info.BlockInfo.View\"}\n\x17StreamBlockInfosRequest\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\r\x12\x10\n\x08max_rank\x18\x02 \x01(\x04\x12\x41\n\x04view\x18\x03 \x01(\x0e\x32\x33.io.casperlabs.casper.consensus.info.BlockInfo.View\"\x8b\x01\n\x14GetDeployInfoRequest\x12\x1a\n\x12\x64\x65ploy_hash_base16\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65ploy_hash\x18\x03 \x01(\x0c\x12\x42\n\x04view\x18\x02 \x01(\x0e\x32\x34.io.casperlabs.casper.consensus.info.DeployInfo.View\"\x8e\x01\n\x19StreamBlockDeploysRequest\x12\x19\n\x11\x62lock_hash_base16\x18\x01 \x01(\t\x12\x12\n\nblock_hash\x18\x03 \x01(\x0c\x12\x42\n\x04view\x18\x02 \x01(\x0e\x32\x34.io.casperlabs.casper.consensus.info.DeployInfo.View\"\xd9\x01\n\nStateQuery\x12I\n\x0bkey_variant\x18\x01 \x01(\x0e\x32\x34.io.casperlabs.node.api.casper.StateQuery.KeyVariant\x12\x12\n\nkey_base16\x18\x02 \x01(\t\x12\x15\n\rpath_segments\x18\x03 \x03(\t\"U\n\nKeyVariant\x12\x1b\n\x17KEY_VARIANT_UNSPECIFIED\x10\x00\x12\x08\n\x04HASH\x10\x01\x12\x08\n\x04UREF\x10\x02\x12\x0b\n\x07\x41\x44\x44RESS\x10\x03\x12\t\n\x05LOCAL\x10\x04\"\x7f\n\x14GetBlockStateRequest\x12\x19\n\x11\x62lock_hash_base16\x18\x01 \x01(\t\x12\x12\n\nblock_hash\x18\x03 \x01(\x0c\x12\x38\n\x05query\x18\x02 \x01(\x0b\x32).io.casperlabs.node.api.casper.StateQuery\"\x86\x01\n\x19\x42\x61tchGetBlockStateRequest\x12\x19\n\x11\x62lock_hash_base16\x18\x01 \x01(\t\x12\x12\n\nblock_hash\x18\x03 \x01(\x0c\x12:\n\x07queries\x18\x02 \x03(\x0b\x32).io.casperlabs.node.api.casper.StateQuery\"m\n\x1a\x42\x61tchGetBlockStateResponse\x12I\n\x06values\x18\x02 \x03(\x0b\x32\x39.io.casperlabs.casper.consensus.state.StoredValueInstanceJ\x04\x08\x01\x10\x02\"\xc2\x01\n\x16ListDeployInfosRequest\x12!\n\x19\x61\x63\x63ount_public_key_base16\x18\x01 \x01(\t\x12\x1a\n\x12\x61\x63\x63ount_public_key\x18\x05 \x01(\x0c\x12\x42\n\x04view\x18\x02 \x01(\x0e\x32\x34.io.casperlabs.casper.consensus.info.DeployInfo.View\x12\x11\n\tpage_size\x18\x03 \x01(\r\x12\x12\n\npage_token\x18\x04 \x01(\t\"\x92\x01\n\x17ListDeployInfosResponse\x12\x45\n\x0c\x64\x65ploy_infos\x18\x01 \x03(\x0b\x32/.io.casperlabs.casper.consensus.info.DeployInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x17\n\x0fprev_page_token\x18\x03 \x01(\t\"e\n GetLastFinalizedBlockInfoRequest\x12\x41\n\x04view\x18\x01 \x01(\x0e\x32\x33.io.casperlabs.casper.consensus.info.BlockInfo.View\"\x8b\x03\n\x13StreamEventsRequest\x12\x13\n\x0b\x62lock_added\x18\x01 \x01(\x08\x12\x17\n\x0f\x62lock_finalized\x18\x02 \x01(\x08\x12\x14\n\x0c\x64\x65ploy_added\x18\x03 \x01(\x08\x12\x18\n\x10\x64\x65ploy_discarded\x18\x04 \x01(\x08\x12\x17\n\x0f\x64\x65ploy_requeued\x18\x05 \x01(\x08\x12\x18\n\x10\x64\x65ploy_processed\x18\x06 \x01(\x08\x12\x18\n\x10\x64\x65ploy_finalized\x18\x07 \x01(\x08\x12\x17\n\x0f\x64\x65ploy_orphaned\x18\x08 \x01(\x08\x12V\n\rdeploy_filter\x18\t \x01(\x0b\x32?.io.casperlabs.node.api.casper.StreamEventsRequest.DeployFilter\x12\x14\n\x0cmin_event_id\x18\n \x01(\x04\x1a\x42\n\x0c\x44\x65ployFilter\x12\x1b\n\x13\x61\x63\x63ount_public_keys\x18\x01 \x03(\x0c\x12\x15\n\rdeploy_hashes\x18\x02 \x03(\x0c\x32\xcd\x0b\n\rCasperService\x12g\n\x06\x44\x65ploy\x12,.io.casperlabs.node.api.casper.DeployRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x07\x64\x65ploys:\x06\x64\x65ploy\x12\x91\x01\n\x0cGetBlockInfo\x12\x32.io.casperlabs.node.api.casper.GetBlockInfoRequest\x1a..io.casperlabs.casper.consensus.info.BlockInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15{block_hash_base16=*}\x12\x8c\x01\n\x10StreamBlockInfos\x12\x36.io.casperlabs.node.api.casper.StreamBlockInfosRequest\x1a..io.casperlabs.casper.consensus.info.BlockInfo\"\x0e\x82\xd3\xe4\x93\x02\x08\x12\x06\x62locks0\x01\x12\x95\x01\n\rGetDeployInfo\x12\x33.io.casperlabs.node.api.casper.GetDeployInfoRequest\x1a/.io.casperlabs.casper.consensus.info.DeployInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16{deploy_hash_base16=*}\x12\x98\x01\n\x12StreamBlockDeploys\x12\x38.io.casperlabs.node.api.casper.StreamBlockDeploysRequest\x1a\x35.io.casperlabs.casper.consensus.Block.ProcessedDeploy\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07\x64\x65ploys0\x01\x12\x80\x01\n\x0cStreamEvents\x12\x32.io.casperlabs.node.api.casper.StreamEventsRequest\x1a*.io.casperlabs.casper.consensus.info.Event\"\x0e\x82\xd3\xe4\x93\x02\x08\x12\x06\x65vents0\x01\x12\x91\x01\n\rGetBlockState\x12\x33.io.casperlabs.node.api.casper.GetBlockStateRequest\x1a\x39.io.casperlabs.casper.consensus.state.StoredValueInstance\"\x10\x82\xd3\xe4\x93\x02\n\"\x05state:\x01*\x12\xa4\x01\n\x12\x42\x61tchGetBlockState\x12\x38.io.casperlabs.node.api.casper.BatchGetBlockStateRequest\x1a\x39.io.casperlabs.node.api.casper.BatchGetBlockStateResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0estate:batchGet:\x01*\x12\x91\x01\n\x0fListDeployInfos\x12\x35.io.casperlabs.node.api.casper.ListDeployInfosRequest\x1a\x36.io.casperlabs.node.api.casper.ListDeployInfosResponse\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07\x64\x65ploys\x12\xaa\x01\n\x19GetLastFinalizedBlockInfo\x12?.io.casperlabs.node.api.casper.GetLastFinalizedBlockInfoRequest\x1a..io.casperlabs.casper.consensus.info.BlockInfo\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14last-finalized-blockb\x06proto3'
  ,
  dependencies=[annotations__pb2.DESCRIPTOR,empty__pb2.DESCRIPTOR,consensus__pb2.DESCRIPTOR,info__pb2.DESCRIPTOR,state__pb2.DESCRIPTOR,])



_STATEQUERY_KEYVARIANT = _descriptor.EnumDescriptor(
  name='KeyVariant',
  full_name='io.casperlabs.node.api.casper.StateQuery.KeyVariant',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KEY_VARIANT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HASH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UREF', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=879,
  serialized_end=964,
)
_sym_db.RegisterEnumDescriptor(_STATEQUERY_KEYVARIANT)


_DEPLOYREQUEST = _descriptor.Descriptor(
  name='DeployRequest',
  full_name='io.casperlabs.node.api.casper.DeployRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='io.casperlabs.node.api.casper.DeployRequest.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=192,
)


_GETBLOCKINFOREQUEST = _descriptor.Descriptor(
  name='GetBlockInfoRequest',
  full_name='io.casperlabs.node.api.casper.GetBlockInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash_base16', full_name='io.casperlabs.node.api.casper.GetBlockInfoRequest.block_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.node.api.casper.GetBlockInfoRequest.block_hash', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.GetBlockInfoRequest.view', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=330,
)


_STREAMBLOCKINFOSREQUEST = _descriptor.Descriptor(
  name='StreamBlockInfosRequest',
  full_name='io.casperlabs.node.api.casper.StreamBlockInfosRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='io.casperlabs.node.api.casper.StreamBlockInfosRequest.depth', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_rank', full_name='io.casperlabs.node.api.casper.StreamBlockInfosRequest.max_rank', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.StreamBlockInfosRequest.view', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=457,
)


_GETDEPLOYINFOREQUEST = _descriptor.Descriptor(
  name='GetDeployInfoRequest',
  full_name='io.casperlabs.node.api.casper.GetDeployInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy_hash_base16', full_name='io.casperlabs.node.api.casper.GetDeployInfoRequest.deploy_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_hash', full_name='io.casperlabs.node.api.casper.GetDeployInfoRequest.deploy_hash', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.GetDeployInfoRequest.view', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=599,
)


_STREAMBLOCKDEPLOYSREQUEST = _descriptor.Descriptor(
  name='StreamBlockDeploysRequest',
  full_name='io.casperlabs.node.api.casper.StreamBlockDeploysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash_base16', full_name='io.casperlabs.node.api.casper.StreamBlockDeploysRequest.block_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.node.api.casper.StreamBlockDeploysRequest.block_hash', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.StreamBlockDeploysRequest.view', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=744,
)


_STATEQUERY = _descriptor.Descriptor(
  name='StateQuery',
  full_name='io.casperlabs.node.api.casper.StateQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_variant', full_name='io.casperlabs.node.api.casper.StateQuery.key_variant', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_base16', full_name='io.casperlabs.node.api.casper.StateQuery.key_base16', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_segments', full_name='io.casperlabs.node.api.casper.StateQuery.path_segments', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATEQUERY_KEYVARIANT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=964,
)


_GETBLOCKSTATEREQUEST = _descriptor.Descriptor(
  name='GetBlockStateRequest',
  full_name='io.casperlabs.node.api.casper.GetBlockStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash_base16', full_name='io.casperlabs.node.api.casper.GetBlockStateRequest.block_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.node.api.casper.GetBlockStateRequest.block_hash', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query', full_name='io.casperlabs.node.api.casper.GetBlockStateRequest.query', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=966,
  serialized_end=1093,
)


_BATCHGETBLOCKSTATEREQUEST = _descriptor.Descriptor(
  name='BatchGetBlockStateRequest',
  full_name='io.casperlabs.node.api.casper.BatchGetBlockStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash_base16', full_name='io.casperlabs.node.api.casper.BatchGetBlockStateRequest.block_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.node.api.casper.BatchGetBlockStateRequest.block_hash', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queries', full_name='io.casperlabs.node.api.casper.BatchGetBlockStateRequest.queries', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1230,
)


_BATCHGETBLOCKSTATERESPONSE = _descriptor.Descriptor(
  name='BatchGetBlockStateResponse',
  full_name='io.casperlabs.node.api.casper.BatchGetBlockStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='io.casperlabs.node.api.casper.BatchGetBlockStateResponse.values', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1232,
  serialized_end=1341,
)


_LISTDEPLOYINFOSREQUEST = _descriptor.Descriptor(
  name='ListDeployInfosRequest',
  full_name='io.casperlabs.node.api.casper.ListDeployInfosRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_public_key_base16', full_name='io.casperlabs.node.api.casper.ListDeployInfosRequest.account_public_key_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_public_key', full_name='io.casperlabs.node.api.casper.ListDeployInfosRequest.account_public_key', index=1,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.ListDeployInfosRequest.view', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='io.casperlabs.node.api.casper.ListDeployInfosRequest.page_size', index=3,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='io.casperlabs.node.api.casper.ListDeployInfosRequest.page_token', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1344,
  serialized_end=1538,
)


_LISTDEPLOYINFOSRESPONSE = _descriptor.Descriptor(
  name='ListDeployInfosResponse',
  full_name='io.casperlabs.node.api.casper.ListDeployInfosResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy_infos', full_name='io.casperlabs.node.api.casper.ListDeployInfosResponse.deploy_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='io.casperlabs.node.api.casper.ListDeployInfosResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_page_token', full_name='io.casperlabs.node.api.casper.ListDeployInfosResponse.prev_page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1541,
  serialized_end=1687,
)


_GETLASTFINALIZEDBLOCKINFOREQUEST = _descriptor.Descriptor(
  name='GetLastFinalizedBlockInfoRequest',
  full_name='io.casperlabs.node.api.casper.GetLastFinalizedBlockInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.GetLastFinalizedBlockInfoRequest.view', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1689,
  serialized_end=1790,
)


_STREAMEVENTSREQUEST_DEPLOYFILTER = _descriptor.Descriptor(
  name='DeployFilter',
  full_name='io.casperlabs.node.api.casper.StreamEventsRequest.DeployFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_public_keys', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.DeployFilter.account_public_keys', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_hashes', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.DeployFilter.deploy_hashes', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2122,
  serialized_end=2188,
)

_STREAMEVENTSREQUEST = _descriptor.Descriptor(
  name='StreamEventsRequest',
  full_name='io.casperlabs.node.api.casper.StreamEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_added', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.block_added', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_finalized', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.block_finalized', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_added', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.deploy_added', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_discarded', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.deploy_discarded', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_requeued', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.deploy_requeued', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_processed', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.deploy_processed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_finalized', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.deploy_finalized', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_orphaned', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.deploy_orphaned', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_filter', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.deploy_filter', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_event_id', full_name='io.casperlabs.node.api.casper.StreamEventsRequest.min_event_id', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STREAMEVENTSREQUEST_DEPLOYFILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1793,
  serialized_end=2188,
)

_DEPLOYREQUEST.fields_by_name['deploy'].message_type = consensus__pb2._DEPLOY
_GETBLOCKINFOREQUEST.fields_by_name['view'].enum_type = info__pb2._BLOCKINFO_VIEW
_STREAMBLOCKINFOSREQUEST.fields_by_name['view'].enum_type = info__pb2._BLOCKINFO_VIEW
_GETDEPLOYINFOREQUEST.fields_by_name['view'].enum_type = info__pb2._DEPLOYINFO_VIEW
_STREAMBLOCKDEPLOYSREQUEST.fields_by_name['view'].enum_type = info__pb2._DEPLOYINFO_VIEW
_STATEQUERY.fields_by_name['key_variant'].enum_type = _STATEQUERY_KEYVARIANT
_STATEQUERY_KEYVARIANT.containing_type = _STATEQUERY
_GETBLOCKSTATEREQUEST.fields_by_name['query'].message_type = _STATEQUERY
_BATCHGETBLOCKSTATEREQUEST.fields_by_name['queries'].message_type = _STATEQUERY
_BATCHGETBLOCKSTATERESPONSE.fields_by_name['values'].message_type = state__pb2._STOREDVALUEINSTANCE
_LISTDEPLOYINFOSREQUEST.fields_by_name['view'].enum_type = info__pb2._DEPLOYINFO_VIEW
_LISTDEPLOYINFOSRESPONSE.fields_by_name['deploy_infos'].message_type = info__pb2._DEPLOYINFO
_GETLASTFINALIZEDBLOCKINFOREQUEST.fields_by_name['view'].enum_type = info__pb2._BLOCKINFO_VIEW
_STREAMEVENTSREQUEST_DEPLOYFILTER.containing_type = _STREAMEVENTSREQUEST
_STREAMEVENTSREQUEST.fields_by_name['deploy_filter'].message_type = _STREAMEVENTSREQUEST_DEPLOYFILTER
DESCRIPTOR.message_types_by_name['DeployRequest'] = _DEPLOYREQUEST
DESCRIPTOR.message_types_by_name['GetBlockInfoRequest'] = _GETBLOCKINFOREQUEST
DESCRIPTOR.message_types_by_name['StreamBlockInfosRequest'] = _STREAMBLOCKINFOSREQUEST
DESCRIPTOR.message_types_by_name['GetDeployInfoRequest'] = _GETDEPLOYINFOREQUEST
DESCRIPTOR.message_types_by_name['StreamBlockDeploysRequest'] = _STREAMBLOCKDEPLOYSREQUEST
DESCRIPTOR.message_types_by_name['StateQuery'] = _STATEQUERY
DESCRIPTOR.message_types_by_name['GetBlockStateRequest'] = _GETBLOCKSTATEREQUEST
DESCRIPTOR.message_types_by_name['BatchGetBlockStateRequest'] = _BATCHGETBLOCKSTATEREQUEST
DESCRIPTOR.message_types_by_name['BatchGetBlockStateResponse'] = _BATCHGETBLOCKSTATERESPONSE
DESCRIPTOR.message_types_by_name['ListDeployInfosRequest'] = _LISTDEPLOYINFOSREQUEST
DESCRIPTOR.message_types_by_name['ListDeployInfosResponse'] = _LISTDEPLOYINFOSRESPONSE
DESCRIPTOR.message_types_by_name['GetLastFinalizedBlockInfoRequest'] = _GETLASTFINALIZEDBLOCKINFOREQUEST
DESCRIPTOR.message_types_by_name['StreamEventsRequest'] = _STREAMEVENTSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeployRequest = _reflection.GeneratedProtocolMessageType('DeployRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.DeployRequest)
  })
_sym_db.RegisterMessage(DeployRequest)

GetBlockInfoRequest = _reflection.GeneratedProtocolMessageType('GetBlockInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKINFOREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.GetBlockInfoRequest)
  })
_sym_db.RegisterMessage(GetBlockInfoRequest)

StreamBlockInfosRequest = _reflection.GeneratedProtocolMessageType('StreamBlockInfosRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOCKINFOSREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.StreamBlockInfosRequest)
  })
_sym_db.RegisterMessage(StreamBlockInfosRequest)

GetDeployInfoRequest = _reflection.GeneratedProtocolMessageType('GetDeployInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEPLOYINFOREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.GetDeployInfoRequest)
  })
_sym_db.RegisterMessage(GetDeployInfoRequest)

StreamBlockDeploysRequest = _reflection.GeneratedProtocolMessageType('StreamBlockDeploysRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOCKDEPLOYSREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.StreamBlockDeploysRequest)
  })
_sym_db.RegisterMessage(StreamBlockDeploysRequest)

StateQuery = _reflection.GeneratedProtocolMessageType('StateQuery', (_message.Message,), {
  'DESCRIPTOR' : _STATEQUERY,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.StateQuery)
  })
_sym_db.RegisterMessage(StateQuery)

GetBlockStateRequest = _reflection.GeneratedProtocolMessageType('GetBlockStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKSTATEREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.GetBlockStateRequest)
  })
_sym_db.RegisterMessage(GetBlockStateRequest)

BatchGetBlockStateRequest = _reflection.GeneratedProtocolMessageType('BatchGetBlockStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETBLOCKSTATEREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.BatchGetBlockStateRequest)
  })
_sym_db.RegisterMessage(BatchGetBlockStateRequest)

BatchGetBlockStateResponse = _reflection.GeneratedProtocolMessageType('BatchGetBlockStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETBLOCKSTATERESPONSE,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.BatchGetBlockStateResponse)
  })
_sym_db.RegisterMessage(BatchGetBlockStateResponse)

ListDeployInfosRequest = _reflection.GeneratedProtocolMessageType('ListDeployInfosRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEPLOYINFOSREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.ListDeployInfosRequest)
  })
_sym_db.RegisterMessage(ListDeployInfosRequest)

ListDeployInfosResponse = _reflection.GeneratedProtocolMessageType('ListDeployInfosResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEPLOYINFOSRESPONSE,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.ListDeployInfosResponse)
  })
_sym_db.RegisterMessage(ListDeployInfosResponse)

GetLastFinalizedBlockInfoRequest = _reflection.GeneratedProtocolMessageType('GetLastFinalizedBlockInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLASTFINALIZEDBLOCKINFOREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.GetLastFinalizedBlockInfoRequest)
  })
_sym_db.RegisterMessage(GetLastFinalizedBlockInfoRequest)

StreamEventsRequest = _reflection.GeneratedProtocolMessageType('StreamEventsRequest', (_message.Message,), {

  'DeployFilter' : _reflection.GeneratedProtocolMessageType('DeployFilter', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEVENTSREQUEST_DEPLOYFILTER,
    '__module__' : 'casper_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.StreamEventsRequest.DeployFilter)
    })
  ,
  'DESCRIPTOR' : _STREAMEVENTSREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.StreamEventsRequest)
  })
_sym_db.RegisterMessage(StreamEventsRequest)
_sym_db.RegisterMessage(StreamEventsRequest.DeployFilter)



_CASPERSERVICE = _descriptor.ServiceDescriptor(
  name='CasperService',
  full_name='io.casperlabs.node.api.casper.CasperService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2191,
  serialized_end=3676,
  methods=[
  _descriptor.MethodDescriptor(
    name='Deploy',
    full_name='io.casperlabs.node.api.casper.CasperService.Deploy',
    index=0,
    containing_service=None,
    input_type=_DEPLOYREQUEST,
    output_type=empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\021\"\007deploys:\006deploy',
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockInfo',
    full_name='io.casperlabs.node.api.casper.CasperService.GetBlockInfo',
    index=1,
    containing_service=None,
    input_type=_GETBLOCKINFOREQUEST,
    output_type=info__pb2._BLOCKINFO,
    serialized_options=b'\202\323\344\223\002\027\022\025{block_hash_base16=*}',
  ),
  _descriptor.MethodDescriptor(
    name='StreamBlockInfos',
    full_name='io.casperlabs.node.api.casper.CasperService.StreamBlockInfos',
    index=2,
    containing_service=None,
    input_type=_STREAMBLOCKINFOSREQUEST,
    output_type=info__pb2._BLOCKINFO,
    serialized_options=b'\202\323\344\223\002\010\022\006blocks',
  ),
  _descriptor.MethodDescriptor(
    name='GetDeployInfo',
    full_name='io.casperlabs.node.api.casper.CasperService.GetDeployInfo',
    index=3,
    containing_service=None,
    input_type=_GETDEPLOYINFOREQUEST,
    output_type=info__pb2._DEPLOYINFO,
    serialized_options=b'\202\323\344\223\002\030\022\026{deploy_hash_base16=*}',
  ),
  _descriptor.MethodDescriptor(
    name='StreamBlockDeploys',
    full_name='io.casperlabs.node.api.casper.CasperService.StreamBlockDeploys',
    index=4,
    containing_service=None,
    input_type=_STREAMBLOCKDEPLOYSREQUEST,
    output_type=consensus__pb2._BLOCK_PROCESSEDDEPLOY,
    serialized_options=b'\202\323\344\223\002\t\022\007deploys',
  ),
  _descriptor.MethodDescriptor(
    name='StreamEvents',
    full_name='io.casperlabs.node.api.casper.CasperService.StreamEvents',
    index=5,
    containing_service=None,
    input_type=_STREAMEVENTSREQUEST,
    output_type=info__pb2._EVENT,
    serialized_options=b'\202\323\344\223\002\010\022\006events',
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockState',
    full_name='io.casperlabs.node.api.casper.CasperService.GetBlockState',
    index=6,
    containing_service=None,
    input_type=_GETBLOCKSTATEREQUEST,
    output_type=state__pb2._STOREDVALUEINSTANCE,
    serialized_options=b'\202\323\344\223\002\n\"\005state:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='BatchGetBlockState',
    full_name='io.casperlabs.node.api.casper.CasperService.BatchGetBlockState',
    index=7,
    containing_service=None,
    input_type=_BATCHGETBLOCKSTATEREQUEST,
    output_type=_BATCHGETBLOCKSTATERESPONSE,
    serialized_options=b'\202\323\344\223\002\023\"\016state:batchGet:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ListDeployInfos',
    full_name='io.casperlabs.node.api.casper.CasperService.ListDeployInfos',
    index=8,
    containing_service=None,
    input_type=_LISTDEPLOYINFOSREQUEST,
    output_type=_LISTDEPLOYINFOSRESPONSE,
    serialized_options=b'\202\323\344\223\002\t\022\007deploys',
  ),
  _descriptor.MethodDescriptor(
    name='GetLastFinalizedBlockInfo',
    full_name='io.casperlabs.node.api.casper.CasperService.GetLastFinalizedBlockInfo',
    index=9,
    containing_service=None,
    input_type=_GETLASTFINALIZEDBLOCKINFOREQUEST,
    output_type=info__pb2._BLOCKINFO,
    serialized_options=b'\202\323\344\223\002\026\022\024last-finalized-block',
  ),
])
_sym_db.RegisterServiceDescriptor(_CASPERSERVICE)

DESCRIPTOR.services_by_name['CasperService'] = _CASPERSERVICE

# @@protoc_insertion_point(module_scope)
